@@ -1,7 +1,7 @@
 #/******************************************************************************
 # * SIENA: Simulation Investigation for Empirical Network Analysis
 # *
-# * Web: http://www.stats.ox.ac.uk/~snijders/siena
+# * Web: https://www.stats.ox.ac.uk/~snijders/siena
 # *
 # * File: phase3.r
 # *
@@ -14,6 +14,17 @@
 ##@phase3 siena07 Does phase 3
 phase3 <- function(z, x, ...)
 {
+	if (is.null(x$lrt))
+	{
+		x$lrt <- FALSE
+	}
+	if (x$lrt)
+	{
+		z$myloglik <- NULL
+		z$myfra <- NULL
+		z$addChainToStore <- TRUE
+	}
+	
     ## initialize phase 3
     f <- FRANstore()
     DisplayTheta(z)
@@ -292,6 +303,7 @@ phase3.2 <- function(z, x, ...)
                      format(sfl, width=8, digits=4),
                      '\n', collapse="", sep=""), cf)
         Report ('\n', cf)
+		z$ac3 <- sfl
     }
     for (j in 1:z$pp)
 	{
@@ -399,6 +411,27 @@ phase3.2 <- function(z, x, ...)
 	z$errorMessage.cov <- errorMessage.cov
 	z$sf.invcov <- NULL
 	## ans<-InstabilityAnalysis(z)
+	
+	if (x$lrt)
+	{
+		z$nGroup <- 1
+		
+		if (ifelse(is.null(x$thermo), FALSE, x$thermo))
+		{
+			z <- thermo(z,x,subphase=4, ...) 
+		}
+		
+		if (ifelse(is.null(x$bridge1), FALSE, x$bridge1))
+		{
+			z <- bridge1(z,x,subphase=4, ...)
+		}
+		
+		z$nbrNodes <- 1
+		f <- FRANstore()
+		.Call("clearStoredChains", PACKAGE=pkgname,
+		f$pModel, keep = 0,1)
+	}
+	
 	z
 }
 
@@ -422,7 +455,7 @@ CalculateDerivative3<- function(z,x)
 			sub <- which(diag(dfra) < 0)
 			dfra[sub,] <- 0
 			dfra[,sub] <- 0
-			dfra[sub, sub] <- 1
+			diag(dfra)[sub] <- 1
 			Report(c("Warning: diagonal element(s)", sub,
 					" of derivative matrix < 0\n"), cf)
 		}
@@ -688,8 +721,20 @@ doPhase1or3Iterations <- function(phase, z, x, zsmall, xsmall, nits, nits6=0,
 		}
 		if (z$int == 1)
 		{
-
-			zz <- x$FRAN(zsmall, xsmall)
+			if (is.null(x$lrt))
+			{
+				x$lrt <- FALSE
+			}
+			if (!x$lrt)
+			{
+				zz <- x$FRAN(zsmall, xsmall)
+			} else {
+				zz <- x$FRAN(zsmall, xsmall, returnLoglik=TRUE, returnChains=TRUE)
+				z$myloglik <- c(z$myloglik, sum(zz$loglik))
+				fra <- colSums(zz$fra) - z$targets
+				z$myfra <- rbind(z$myfra, fra)
+			}
+			
 			if (!zz$OK)
 			{
 				z$OK <- zz$OK
