@@ -5,7 +5,7 @@
 
 // R stuff last redefine length macro
 #include <R.h>
-//#include <Rinternals.h> // included by siena07models.h
+#include <Rinternals.h>
 #include <R_ext/Rdynload.h>
 
 extern "C"
@@ -21,11 +21,11 @@ extern "C"
 
 static const R_CallMethodDef CallEntries[] = {
    CALLDEF(Behavior, 2),
-    CALLDEF(Continuous, 2),
+   CALLDEF(Continuous, 2),
    CALLDEF(Bipartite, 2),
    CALLDEF(ChangingCovariates, 2),
    CALLDEF(ChangingDyadicCovariates, 2),
-	CALLDEF(clearStoredChains, 3),
+   CALLDEF(clearStoredChains, 3),
    CALLDEF(ConstantCovariates, 2),
    CALLDEF(Constraints, 7),
    CALLDEF(deleteData, 1),
@@ -34,11 +34,12 @@ static const R_CallMethodDef CallEntries[] = {
    CALLDEF(effects, 2),
    CALLDEF(ExogEvent, 2),
    CALLDEF(forwardModel, 16),
+   CALLDEF(getChainProbabilities, 8),
    CALLDEF(getTargets, 6),
    CALLDEF(interactionEffects, 2),
    CALLDEF(mlInitializeSubProcesses, 10),
    CALLDEF(mlMakeChains, 9),
-	CALLDEF(mlPeriod, 14),
+   CALLDEF(mlPeriod, 14),
    CALLDEF(OneMode, 2),
    CALLDEF(setupData, 2),
    CALLDEF(setupModelOptions, 12),
