@@ -29,10 +29,23 @@ public:
 	virtual double calculateContribution(int alter) const;
 
 protected:
-	virtual double statistic(const Network * pSummationTieNetwork) const;
+	virtual void initializeStatisticCalculation();
+	virtual void onNextEgo(int ego);
+	virtual double tieStatistic(int alter);
+	virtual void cleanupStatisticCalculation();
 
 private:
 	int ldensity;
+
+	// A helper array of marks for statistic calculations
+	int * lmark;
+
+	// Given an ego i
+	// mark[h] = baseMark + 2 if there are mutual ties between i and h,
+	// mark[h] = baseMark + 1 if only one of the mutual ties is present,
+	// mark[h] <= baseMark otherwise.
+
+	int lbaseMark;
 };
 
 }
