@@ -44,7 +44,7 @@ public:
 		int period,
 		Cache * pCache);
 
-	virtual double value(int alter);
+	virtual double value(int alter) const;
 	void pFunction(double (* pFunction)(double));
 
 private:
