@@ -23,7 +23,7 @@ class CovariateDistance2EgoAltSimNetworkFunction: public
 public:
 	CovariateDistance2EgoAltSimNetworkFunction(std::string networkName,
 		std::string covariateName, bool excludeMissing, bool outgoing);
-	virtual double value(int alter);
+	virtual double value(int alter) const;
 
 private:
 	bool lexcludeMissing;
