@@ -24,7 +24,7 @@ public:
 	CovariateDistance2SimilarityNetworkFunction(std::string networkName,
 		std::string covariateName, bool excludeMissing);
 
-	virtual double value(int alter);
+	virtual double value(int alter) const;
 
 private:
 	bool lexcludeMissing;
