@@ -45,7 +45,7 @@ public:
 		State * pState, int period, Cache * pCache);
 
 protected:
-	double value(int i) const;
+	double covvalue(int i) const;
 	bool missing(int i) const;
 	double actor_similarity(int i, int j) const;
 	ConstantCovariate * pConstantCovariate() const;
