@@ -24,7 +24,7 @@ class BehaviorLongitudinalData;
  */
 class CovariatePredicate: public AlterPredicate, NamedObject {
 public:
-	CovariatePredicate(string covariateName);
+	CovariatePredicate(std::string covariateName);
 	virtual ~CovariatePredicate() {}
 	virtual void initialize(const Data * pData, State * pState, int period,
 			Cache * pCache);
