@@ -33,7 +33,7 @@ public:
 		Cache * pCache);
 	virtual void preprocessEgo(int ego);
 
-	virtual double value(int alter);
+	virtual double value(int alter) const;
 
 private:
 	AlterFunction * lpFunction;
