@@ -26,7 +26,7 @@ public:
 	virtual void initialize(const Data * pData,
 		State * pState, int period, Cache * pCache);
 
-	virtual double value(int alter);
+	virtual double value(int alter) const;
 
 private:
 	bool lexcludeMissing;
