@@ -15,7 +15,8 @@
  */
 #include <vector>
 #include <cstring>
-// #include <Rinternals.h> // included by siena07internals.h
+#include <Rinternals.h>
+#undef length
 #include "siena07internals.h"
 #include "data/Data.h"
 #include "data/LongitudinalData.h"
@@ -146,64 +147,64 @@ void getColNos(SEXP Names, int * netTypeCol, int * nameCol, int * effectCol,
 	}
 	if (*netTypeCol < 0)
 	{
-		Rf_error("cannot find nettype");
+		error("cannot find nettype");
 	}
 	if (*nameCol < 0)
 	{
-		Rf_error("cannot find network name");
+		error("cannot find network name");
 	}
 	if (*effectCol < 0)
 	{
-		Rf_error("cannot find effectName");
+		error("cannot find effectName");
 	}
 	if (*parmCol < 0)
 	{
-		Rf_error("cannot find internal parameter");
+		error("cannot find internal parameter");
 	}
 	if (*int1Col < 0)
 	{
-		Rf_error("cannot find interaction1");
+		error("cannot find interaction1");
         }
 
 	if (*int2Col < 0)
 	{
-		Rf_error("cannot find interaction2");
+		error("cannot find interaction2");
 	}
 	if (*initValCol < 0)
 	{
-		Rf_error("cannot find initial value");
+		error("cannot find initial value");
 	}
 	if (*groupCol < 0)
 	{
-		Rf_error("cannot find group");
+		error("cannot find group");
 	}
 	if (*periodCol < 0)
 	{
-		Rf_error("cannot find period");
+		error("cannot find period");
 	}
 	if (*pointerCol < 0)
 	{
-		Rf_error("cannot find effect pointer");
+		error("cannot find effect pointer");
 	}
 	if (*rateTypeCol < 0)
 	{
-		Rf_error("cannot find rate type");
+		error("cannot find rate type");
 	}
 	if (*intptr1Col < 0)
 	{
-		Rf_error("cannot find effect1");
+		error("cannot find effect1");
 	}
 	if (*intptr2Col < 0)
 	{
-		Rf_error("cannot find effect2");
+		error("cannot find effect2");
 	}
 	if (*intptr3Col < 0)
 	{
-		Rf_error("cannot find effect3");
+		error("cannot find effect3");
 	}
 	if (*settingCol < 0)
 	{
-		Rf_error("cannot find setting col; reconstruct effects object with this version of RSiena");
+		error("cannot find setting col; reconstruct effects object with this version of RSiena");
 	}
 	//Rprintf("%d parmcol\n", *parmCol);
 }
@@ -216,8 +217,8 @@ void updateParameters(SEXP EFFECTSLIST, SEXP THETA, vector<Data *> *
 {
 	// get the column names from the names attribute
 	SEXP cols;
-	PROTECT(cols = Rf_install("names"));
-	SEXP Names = Rf_getAttrib(VECTOR_ELT(EFFECTSLIST, 0), cols);
+	PROTECT(cols = install("names"));
+	SEXP Names = getAttrib(VECTOR_ELT(EFFECTSLIST, 0), cols);
 
 	int netTypeCol; /* net type */
 	int nameCol; /* network name */
@@ -303,7 +304,7 @@ void updateParameters(SEXP EFFECTSLIST, SEXP THETA, vector<Data *> *
 				 	}
 				 	else
 				 	{
-				 		Rf_error("setting found for behavior variable %s",
+				 		error("setting found for behavior variable %s",
 				 			networkName);
 				 	}
 				}
@@ -318,7 +319,7 @@ void updateParameters(SEXP EFFECTSLIST, SEXP THETA, vector<Data *> *
 				}
 			else
 			{
-					Rf_error("setting found for behavior variable %s", 
+					error("setting found for behavior variable %s", 
 						networkName);
 				}
 			}
@@ -352,7 +353,7 @@ void setupOneModeNetwork(SEXP ONEMODE,
 	//Rprintf("%x\n", pNetworkData);
 	SEXP ONEMODEVALS = VECTOR_ELT(ONEMODE, 0);
 	int *start = INTEGER(ONEMODEVALS);
-	int listlen = Rf_ncols(ONEMODEVALS);
+	int listlen = ncols(ONEMODEVALS);
 	int pos = 0;
 
 	for (int row = 0; row < listlen; row++)
@@ -370,7 +371,7 @@ void setupOneModeNetwork(SEXP ONEMODE,
 
 	ONEMODEVALS = VECTOR_ELT(ONEMODE, 1);
 	start = INTEGER(ONEMODEVALS);
-	listlen = Rf_ncols(ONEMODEVALS);
+	listlen = ncols(ONEMODEVALS);
 	pos = 0;
 
 	for (int row = 0; row < listlen; row++)
@@ -388,7 +389,7 @@ void setupOneModeNetwork(SEXP ONEMODE,
 
 	ONEMODEVALS = VECTOR_ELT(ONEMODE, 2);
 	start = INTEGER(ONEMODEVALS);
-	listlen = Rf_ncols(ONEMODEVALS);
+	listlen = ncols(ONEMODEVALS);
 	pos = 0;
 
 	for (int row = 0; row < listlen; row++)
@@ -414,16 +415,16 @@ void setupOneModeObservations(const std::string& name, SEXP ONEMODES,
 	int observations = Rf_length(ONEMODES);
 	if (observations != pOneModeNetworkLongitudinalData->observationCount())
 	{
-		Rf_error(("wrong number of observations in: " + name + ": expected "
+		error(("wrong number of observations in: " + name + ": expected "
 				+ toString(pOneModeNetworkLongitudinalData->observationCount()) + " got "
 				+ toString(observations)).c_str());
 	}
 	SEXP uo;
-	PROTECT(uo = Rf_install("uponly"));
-	SEXP uponly = Rf_getAttrib(ONEMODES, uo);
+	PROTECT(uo = install("uponly"));
+	SEXP uponly = getAttrib(ONEMODES, uo);
 	SEXP dow;
-	PROTECT(dow = Rf_install("downonly"));
-	SEXP downonly = Rf_getAttrib(ONEMODES, dow);
+	PROTECT(dow = install("downonly"));
+	SEXP downonly = getAttrib(ONEMODES, dow);
 
 	for (int period = 0; period < (observations - 1); period++)
 	{
@@ -451,32 +452,32 @@ void setupOneModeGroup(SEXP ONEMODEGROUP, Data * pData)
 	for (int oneMode = 0; oneMode < nOneMode; oneMode++)
 	{
 		SEXP ONEMODES = VECTOR_ELT(ONEMODEGROUP, oneMode);
-		SEXP as = PROTECT(Rf_install("nodeSet"));
-		SEXP actorSet = PROTECT(Rf_getAttrib(ONEMODES, as));
-		SEXP symm = PROTECT(Rf_install("symmetric"));
-		SEXP symmetric = PROTECT(Rf_getAttrib(ONEMODES, symm));
-		SEXP balm = PROTECT(Rf_install("balmean"));
-		SEXP balmean = PROTECT(Rf_getAttrib(ONEMODES, balm));
-		SEXP strm = PROTECT(Rf_install("structmean"));
-		SEXP structmean = PROTECT(Rf_getAttrib(ONEMODES, strm));
-		SEXP avin = PROTECT(Rf_install("averageInDegree"));
-		SEXP averageInDegree = PROTECT(Rf_getAttrib(ONEMODES, avin));
-		SEXP avout = PROTECT(Rf_install("averageOutDegree"));
-		SEXP averageOutDegree = PROTECT(Rf_getAttrib(ONEMODES, avout));
+		SEXP as = PROTECT(install("nodeSet"));
+		SEXP actorSet = PROTECT(getAttrib(ONEMODES, as));
+		SEXP symm = PROTECT(install("symmetric"));
+		SEXP symmetric = PROTECT(getAttrib(ONEMODES, symm));
+		SEXP balm = PROTECT(install("balmean"));
+		SEXP balmean = PROTECT(getAttrib(ONEMODES, balm));
+		SEXP strm = PROTECT(install("structmean"));
+		SEXP structmean = PROTECT(getAttrib(ONEMODES, strm));
+		SEXP avin = PROTECT(install("averageInDegree"));
+		SEXP averageInDegree = PROTECT(getAttrib(ONEMODES, avin));
+		SEXP avout = PROTECT(install("averageOutDegree"));
+		SEXP averageOutDegree = PROTECT(getAttrib(ONEMODES, avout));
 
-		SEXP nm = PROTECT(Rf_install("name"));
-		SEXP name = Rf_getAttrib(ONEMODES, nm);
+		SEXP nm = PROTECT(install("name"));
+		SEXP name = getAttrib(ONEMODES, nm);
 		const ActorSet* pActorSet = pData->pActorSet(CHAR(STRING_ELT(actorSet, 0)));
 		const char* cname = CHAR(STRING_ELT(name, 0));
 		OneModeNetworkLongitudinalData *  pNetData = pData->createOneModeNetworkData(cname, pActorSet);
 
 		// parse settings
-		SEXP settingsSymbol = PROTECT(Rf_install("settingsinfo"));
-		SEXP settingsList = PROTECT(Rf_getAttrib(ONEMODES, settingsSymbol));
+		SEXP settingsSymbol = PROTECT(install("settingsinfo"));
+		SEXP settingsList = PROTECT(getAttrib(ONEMODES, settingsSymbol));
 		for (int j = 0; j < Rf_length(settingsList); j++)
 		{
 			SEXP settingInfo = VECTOR_ELT(settingsList, j);
-			SEXP infoNames = Rf_getAttrib(settingInfo, R_NamesSymbol);
+			SEXP infoNames = getAttrib(settingInfo, R_NamesSymbol);
 			std::string id, type, covar, only;
 //			Rprintf("setting %d\n", j);
 			// parse key value list
@@ -495,8 +496,8 @@ void setupOneModeGroup(SEXP ONEMODEGROUP, Data * pData)
 			if      (only == "up")   permType = Permission_Type::UP;
 			else if (only == "down") permType = Permission_Type::DOWN;
 			// asserts
-			if (id.length() == 0) Rf_error("settings id should not be empty");
-			if (type.length() == 0) Rf_error("settings type should not be empty");
+			if (id.length() == 0) error("settings id should not be empty");
+			if (type.length() == 0) error("settings type should not be empty");
 			// add it
 			Rprintf("%s %s %s %s\n", id.c_str(), type.c_str(), covar.c_str(), only.c_str());
 			pNetData->addSettingName(id, type, covar, permType);
@@ -504,12 +505,12 @@ void setupOneModeGroup(SEXP ONEMODEGROUP, Data * pData)
 
 		// check first two setting types
 		if (pNetData->rSettingNames().size() == 1) {
-			Rf_error("if setting are present use universal and primary");
+			error("if setting are present use universal and primary");
 		} else if (pNetData->rSettingNames().size() >= 2) {
 			if (pNetData->rSettingNames().at(0).getSettingType() != "universal")
-				Rf_error("first setting should be type=universal");
+				error("first setting should be type=universal");
 			if (pNetData->rSettingNames().at(1).getSettingType() != "primary")
-				Rf_error("second setting should be type=primary");
+				error("second setting should be type=primary");
 		}
 
 		pNetData->symmetric(*(LOGICAL(symmetric)));
@@ -565,7 +566,7 @@ void setupBipartiteNetwork(SEXP BIPARTITE,
 
 	SEXP BIPARTITEVALS = VECTOR_ELT(BIPARTITE, 0);
 	int *start = INTEGER(BIPARTITEVALS);
-	int listlen = Rf_ncols(BIPARTITEVALS);
+	int listlen = ncols(BIPARTITEVALS);
 	int pos = 0;
 
 	for (int row = 0; row < listlen; row++)
@@ -583,7 +584,7 @@ void setupBipartiteNetwork(SEXP BIPARTITE,
 
 	BIPARTITEVALS = VECTOR_ELT(BIPARTITE, 1);
 	start = INTEGER(BIPARTITEVALS);
-	listlen = Rf_ncols(BIPARTITEVALS);
+	listlen = ncols(BIPARTITEVALS);
 	pos = 0;
 
 	for (int row = 0; row < listlen; row++)
@@ -601,7 +602,7 @@ void setupBipartiteNetwork(SEXP BIPARTITE,
 
 	BIPARTITEVALS = VECTOR_ELT(BIPARTITE, 2);
 	start = INTEGER(BIPARTITEVALS);
-	listlen = Rf_ncols(BIPARTITEVALS);
+	listlen = ncols(BIPARTITEVALS);
 	pos = 0;
 
 	for (int row = 0; row < listlen; row++)
@@ -629,14 +630,14 @@ void setupBipartiteObservations(SEXP BIPARTITES,
     int observations = Rf_length(BIPARTITES);
     if (observations != pNetworkLongitudinalData->observationCount())
     {
-		Rf_error ("wrong number of observations in bipartite");
+		error ("wrong number of observations in bipartite");
     }
     SEXP uo;
-    PROTECT(uo = Rf_install("uponly"));
-    SEXP uponly = Rf_getAttrib(BIPARTITES, uo);
+    PROTECT(uo = install("uponly"));
+    SEXP uponly = getAttrib(BIPARTITES, uo);
     SEXP dow;
-    PROTECT(dow = Rf_install("downonly"));
-    SEXP downonly = Rf_getAttrib(BIPARTITES, dow);
+    PROTECT(dow = install("downonly"));
+    SEXP downonly = getAttrib(BIPARTITES, dow);
     for (int period = 0; period < (observations - 1); period++)
     {
         pNetworkLongitudinalData->upOnly(period,
@@ -663,14 +664,14 @@ void setupBipartiteGroup(SEXP BIPARTITEGROUP, Data * pData)
 	for (int bipartite = 0; bipartite < nBipartite; bipartite++)
 	{
 		SEXP as;
-		PROTECT(as = Rf_install("nodeSet"));
-		SEXP actorSet = Rf_getAttrib(VECTOR_ELT(BIPARTITEGROUP, bipartite), as);
+		PROTECT(as = install("nodeSet"));
+		SEXP actorSet = getAttrib(VECTOR_ELT(BIPARTITEGROUP, bipartite), as);
 		SEXP nm;
-		PROTECT(nm = Rf_install("name"));
-		SEXP name = Rf_getAttrib(VECTOR_ELT(BIPARTITEGROUP, bipartite), nm);
+		PROTECT(nm = install("name"));
+		SEXP name = getAttrib(VECTOR_ELT(BIPARTITEGROUP, bipartite), nm);
 		SEXP avout;
-		PROTECT(avout = Rf_install("averageOutDegree"));
-		SEXP averageOutDegree = Rf_getAttrib(VECTOR_ELT(BIPARTITEGROUP,
+		PROTECT(avout = install("averageOutDegree"));
+		SEXP averageOutDegree = getAttrib(VECTOR_ELT(BIPARTITEGROUP,
 					bipartite), avout);
 		const ActorSet * pSenders = pData->pActorSet(CHAR(STRING_ELT(
 						actorSet, 0)));
@@ -697,17 +698,17 @@ void setupBipartiteGroup(SEXP BIPARTITEGROUP, Data * pData)
  */
 void setupBehavior(SEXP BEHAVIOR, BehaviorLongitudinalData * pBehaviorData)
 {
-	int observations = Rf_ncols(VECTOR_ELT(BEHAVIOR, 0));
+	int observations = ncols(VECTOR_ELT(BEHAVIOR, 0));
 
 	if (observations != pBehaviorData->observationCount())
 	{
-		Rf_error ("wrong number of observations in Behavior");
+		error ("wrong number of observations in Behavior");
 	}
-	int nActors = Rf_nrows(VECTOR_ELT(BEHAVIOR, 0));
+	int nActors = nrows(VECTOR_ELT(BEHAVIOR, 0));
 
 	if (nActors != pBehaviorData->n())
 	{
-		Rf_error ("wrong number of actors");
+		error ("wrong number of actors");
 	}
 	int * start = INTEGER(VECTOR_ELT(BEHAVIOR, 0));
 	int * missing = LOGICAL(VECTOR_ELT(BEHAVIOR, 1));
@@ -721,25 +722,25 @@ void setupBehavior(SEXP BEHAVIOR, BehaviorLongitudinalData * pBehaviorData)
 		}
 	}
 	SEXP uo;
-	PROTECT(uo = Rf_install("uponly"));
-	SEXP uponly = Rf_getAttrib(VECTOR_ELT(BEHAVIOR, 0), uo);
+	PROTECT(uo = install("uponly"));
+	SEXP uponly = getAttrib(VECTOR_ELT(BEHAVIOR, 0), uo);
 	SEXP dow;
-	PROTECT(dow = Rf_install("downonly"));
-	SEXP downonly = Rf_getAttrib(VECTOR_ELT(BEHAVIOR,0), dow);
+	PROTECT(dow = install("downonly"));
+	SEXP downonly = getAttrib(VECTOR_ELT(BEHAVIOR,0), dow);
 	for (int period = 0; period < (observations - 1); period++)
 	{
 		pBehaviorData->upOnly(period, LOGICAL(uponly)[period]);
 		pBehaviorData->downOnly(period, LOGICAL(downonly)[period]);
 	}
 	SEXP sim;
-	PROTECT(sim = Rf_install("simMean"));
-	SEXP simMean = Rf_getAttrib(VECTOR_ELT(BEHAVIOR,0), sim);
+	PROTECT(sim = install("simMean"));
+	SEXP simMean = getAttrib(VECTOR_ELT(BEHAVIOR,0), sim);
 	pBehaviorData->similarityMean(REAL(simMean)[0]);
 	SEXP sims;
-	PROTECT(sims = Rf_install("simMeans"));
-	SEXP simMeans = Rf_getAttrib(VECTOR_ELT(BEHAVIOR, 0), sims);
+	PROTECT(sims = install("simMeans"));
+	SEXP simMeans = getAttrib(VECTOR_ELT(BEHAVIOR, 0), sims);
 	SEXP simNames;
-	PROTECT(simNames = Rf_getAttrib(simMeans, R_NamesSymbol));
+	PROTECT(simNames = getAttrib(simMeans, R_NamesSymbol));
 	int numberNetworks = Rf_length(simMeans);
 	for (int net = 0; net < numberNetworks; net++)
 	{
@@ -763,13 +764,13 @@ void setupBehaviorGroup(SEXP BEHGROUP, Data *pData)
 	for (int behavior= 0; behavior < nBehavior; behavior++)
 	{
 		SEXP as;
-		PROTECT(as = Rf_install("nodeSet"));
-		SEXP actorSet = Rf_getAttrib(VECTOR_ELT(VECTOR_ELT(BEHGROUP, behavior), 0),
+		PROTECT(as = install("nodeSet"));
+		SEXP actorSet = getAttrib(VECTOR_ELT(VECTOR_ELT(BEHGROUP, behavior), 0),
 				as);
 
 		SEXP nm;
-		PROTECT(nm = Rf_install("name"));
-		SEXP name = Rf_getAttrib(VECTOR_ELT(VECTOR_ELT(BEHGROUP, behavior), 0),
+		PROTECT(nm = install("name"));
+		SEXP name = getAttrib(VECTOR_ELT(VECTOR_ELT(BEHGROUP, behavior), 0),
 				nm);
 
 		const ActorSet * pActorSet = pData->pActorSet(CHAR(STRING_ELT(
@@ -789,17 +790,17 @@ void setupBehaviorGroup(SEXP BEHGROUP, Data *pData)
 void setupContinuous(SEXP CONTINUOUS, ContinuousLongitudinalData * 
 	pContinuousData)
 {
-    int observations = Rf_ncols(VECTOR_ELT(CONTINUOUS, 0));
+    int observations = ncols(VECTOR_ELT(CONTINUOUS, 0));
 
     if (observations != pContinuousData->observationCount())
     {
-		Rf_error ("wrong number of observations in Continuous");
+		error ("wrong number of observations in Continuous");
     }
-    int nActors = Rf_nrows(VECTOR_ELT(CONTINUOUS, 0));
+    int nActors = nrows(VECTOR_ELT(CONTINUOUS, 0));
 
     if (nActors != pContinuousData->n())
     {
-        Rf_error ("wrong number of actors");
+        error ("wrong number of actors");
     }
     double * start = REAL(VECTOR_ELT(CONTINUOUS, 0));
 	int * missing = LOGICAL(VECTOR_ELT(CONTINUOUS, 1));
@@ -813,25 +814,25 @@ void setupContinuous(SEXP CONTINUOUS, ContinuousLongitudinalData *
         }
     }
     SEXP uo;
-    PROTECT(uo = Rf_install("uponly"));
-    SEXP uponly = Rf_getAttrib(VECTOR_ELT(CONTINUOUS, 0), uo);
+    PROTECT(uo = install("uponly"));
+    SEXP uponly = getAttrib(VECTOR_ELT(CONTINUOUS, 0), uo);
     SEXP dow;
-    PROTECT(dow = Rf_install("downonly"));
-    SEXP downonly = Rf_getAttrib(VECTOR_ELT(CONTINUOUS,0), dow);
+    PROTECT(dow = install("downonly"));
+    SEXP downonly = getAttrib(VECTOR_ELT(CONTINUOUS,0), dow);
     for (int period = 0; period < (observations - 1); period++)
     {
         pContinuousData->upOnly(period, LOGICAL(uponly)[period]);
         pContinuousData->downOnly(period, LOGICAL(downonly)[period]);
     }
     SEXP sim;
-    PROTECT(sim = Rf_install("simMean"));
-    SEXP simMean = Rf_getAttrib(VECTOR_ELT(CONTINUOUS,0), sim);
+    PROTECT(sim = install("simMean"));
+    SEXP simMean = getAttrib(VECTOR_ELT(CONTINUOUS,0), sim);
 	pContinuousData->similarityMean(REAL(simMean)[0]);
 	SEXP sims;
-	PROTECT(sims = Rf_install("simMeans"));
-	SEXP simMeans = Rf_getAttrib(VECTOR_ELT(CONTINUOUS, 0), sims);
+	PROTECT(sims = install("simMeans"));
+	SEXP simMeans = getAttrib(VECTOR_ELT(CONTINUOUS, 0), sims);
 	SEXP simNames;
-	PROTECT(simNames = Rf_getAttrib(simMeans, R_NamesSymbol));
+	PROTECT(simNames = getAttrib(simMeans, R_NamesSymbol));
 	int numberNetworks = Rf_length(simMeans);
 	for (int net = 0; net < numberNetworks; net++)
 	{
@@ -854,13 +855,13 @@ void setupContinuousGroup(SEXP CONTGROUP, Data *pData)
     for (int continuous = 0; continuous < nCont; continuous++)
     {
 		SEXP as;
-		PROTECT(as = Rf_install("nodeSet"));
-        SEXP actorSet = Rf_getAttrib(VECTOR_ELT(VECTOR_ELT(CONTGROUP, continuous), 0),
+		PROTECT(as = install("nodeSet"));
+        SEXP actorSet = getAttrib(VECTOR_ELT(VECTOR_ELT(CONTGROUP, continuous), 0),
 								  as);
 
         SEXP nm;
-        PROTECT(nm = Rf_install("name"));
-        SEXP name = Rf_getAttrib(VECTOR_ELT(VECTOR_ELT(CONTGROUP, continuous), 0),
+        PROTECT(nm = install("name"));
+        SEXP name = getAttrib(VECTOR_ELT(VECTOR_ELT(CONTGROUP, continuous), 0),
 							  nm);
 
         const ActorSet * myActorSet = pData->pActorSet(CHAR(STRING_ELT(
@@ -882,21 +883,21 @@ void setupConstantCovariate(SEXP COCOVAR,
 	// Rprintf("%x\n", pConstantCovariate);
 	double * start = REAL(COCOVAR);
 	SEXP mn;
-	PROTECT(mn = Rf_install("mean"));
-	SEXP ans = Rf_getAttrib(COCOVAR, mn);
+	PROTECT(mn = install("mean"));
+	SEXP ans = getAttrib(COCOVAR, mn);
 	double mean = REAL(ans)[0];
 	SEXP cn;
-	PROTECT(cn = Rf_install("centered"));
-	ans = Rf_getAttrib(COCOVAR, cn);
+	PROTECT(cn = install("centered"));
+	ans = getAttrib(COCOVAR, cn);
 	bool centered = LOGICAL(ans)[0];
 
 	// extract imputationValues if provided by user
 	SEXP im;
-	PROTECT(im = Rf_install("imputationValues"));
-	ans = Rf_getAttrib(COCOVAR, im);
+	PROTECT(im = install("imputationValues"));
+	ans = getAttrib(COCOVAR, im);
 	bool impute = FALSE;
 	double * imputationValues;
-	if(!Rf_isNull(ans))
+	if(!isNull(ans))
 	{
 		impute = TRUE;
 		imputationValues = REAL(ans);
@@ -947,12 +948,12 @@ void setupConstantCovariateGroup(SEXP COCOVARGROUP, Data *pData)
 			constantCovariate++)
 	{
 		SEXP as;
-		PROTECT(as = Rf_install("nodeSet"));
-		SEXP actorSet = Rf_getAttrib(VECTOR_ELT(COCOVARGROUP, constantCovariate),
+		PROTECT(as = install("nodeSet"));
+		SEXP actorSet = getAttrib(VECTOR_ELT(COCOVARGROUP, constantCovariate),
 				as);
 		SEXP nm;
-		PROTECT(nm = Rf_install("name"));
-		SEXP name = Rf_getAttrib(VECTOR_ELT(COCOVARGROUP, constantCovariate), nm);
+		PROTECT(nm = install("name"));
+		SEXP name = getAttrib(VECTOR_ELT(COCOVARGROUP, constantCovariate), nm);
 		const ActorSet * pActorSet = pData->pActorSet(CHAR(STRING_ELT(
 						actorSet, 0)));
 		int nActors = Rf_length(VECTOR_ELT(COCOVARGROUP, constantCovariate));
@@ -960,7 +961,7 @@ void setupConstantCovariateGroup(SEXP COCOVARGROUP, Data *pData)
 
 		if (nActors != pActorSet->n())
 		{
-			Rf_error ("wrong number of actors");
+			error ("wrong number of actors");
 		}
 		ConstantCovariate * pConstantCovariate =
 			pData->createConstantCovariate(CHAR(STRING_ELT(name, 0)),
@@ -968,11 +969,11 @@ void setupConstantCovariateGroup(SEXP COCOVARGROUP, Data *pData)
 		setupConstantCovariate(VECTOR_ELT(COCOVARGROUP,	constantCovariate),
 				pConstantCovariate);
 		SEXP mn;
-		PROTECT(mn = Rf_install("mean"));
-		SEXP obsmean = Rf_getAttrib(VECTOR_ELT(COCOVARGROUP, constantCovariate), mn);
+		PROTECT(mn = install("mean"));
+		SEXP obsmean = getAttrib(VECTOR_ELT(COCOVARGROUP, constantCovariate), mn);
 		SEXP cn;
-		PROTECT(cn = Rf_install("centered"));
-		SEXP ans = Rf_getAttrib(VECTOR_ELT(COCOVARGROUP, constantCovariate), cn);
+		PROTECT(cn = install("centered"));
+		SEXP ans = getAttrib(VECTOR_ELT(COCOVARGROUP, constantCovariate), cn);
 		bool centered = LOGICAL(ans)[0];
 		if (centered)
 		{
@@ -983,16 +984,16 @@ void setupConstantCovariateGroup(SEXP COCOVARGROUP, Data *pData)
 			pConstantCovariate->mean(REAL(obsmean)[0]);
 		}
 		SEXP sim;
-		PROTECT(sim = Rf_install("simMean"));
-		SEXP simMean = Rf_getAttrib(VECTOR_ELT(COCOVARGROUP, constantCovariate),
+		PROTECT(sim = install("simMean"));
+		SEXP simMean = getAttrib(VECTOR_ELT(COCOVARGROUP, constantCovariate),
 				sim);
 		pConstantCovariate->similarityMean(REAL(simMean)[0]);
 		SEXP sims;
-		PROTECT(sims = Rf_install("simMeans"));
-		SEXP simMeans = Rf_getAttrib(VECTOR_ELT(COCOVARGROUP, constantCovariate),
+		PROTECT(sims = install("simMeans"));
+		SEXP simMeans = getAttrib(VECTOR_ELT(COCOVARGROUP, constantCovariate),
 				sims);
 		SEXP simNames;
-		PROTECT(simNames = Rf_getAttrib(simMeans, R_NamesSymbol));
+		PROTECT(simNames = getAttrib(simMeans, R_NamesSymbol));
 		int numberNetworks = Rf_length(simMeans);
 		for (int net = 0; net < numberNetworks; net++)
 		{
@@ -1000,8 +1001,8 @@ void setupConstantCovariateGroup(SEXP COCOVARGROUP, Data *pData)
 					CHAR(STRING_ELT(simNames, net)));
 		}
 		SEXP range;
-		PROTECT(range = Rf_install("range"));
-		SEXP Range = Rf_getAttrib(VECTOR_ELT(COCOVARGROUP, constantCovariate),
+		PROTECT(range = install("range"));
+		SEXP Range = getAttrib(VECTOR_ELT(COCOVARGROUP, constantCovariate),
 				range);
 		pConstantCovariate->range(REAL(Range)[0]);
 		UNPROTECT(8);
@@ -1015,25 +1016,25 @@ void setupConstantCovariateGroup(SEXP COCOVARGROUP, Data *pData)
 void setupChangingCovariate(SEXP VARCOVAR,
 		ChangingCovariate * pChangingCovariate)
 {
-	int observations = Rf_ncols(VARCOVAR);
-	int nActors = Rf_nrows(VARCOVAR);
+	int observations = ncols(VARCOVAR);
+	int nActors = nrows(VARCOVAR);
 	double * start = REAL(VARCOVAR);
 	SEXP mn;
-	PROTECT(mn = Rf_install("mean"));
-	SEXP ans = Rf_getAttrib(VARCOVAR, mn);
+	PROTECT(mn = install("mean"));
+	SEXP ans = getAttrib(VARCOVAR, mn);
 	double mean = REAL(ans)[0];
 	SEXP cn;
-	PROTECT(cn = Rf_install("centered"));
-	ans = Rf_getAttrib(VARCOVAR, cn);
+	PROTECT(cn = install("centered"));
+	ans = getAttrib(VARCOVAR, cn);
 	bool centered = LOGICAL(ans)[0];
 
 	// extract imputationValues if provided by user
 	SEXP im;
-	PROTECT(im = Rf_install("imputationValues"));
-	ans = Rf_getAttrib(VARCOVAR, im);
+	PROTECT(im = install("imputationValues"));
+	ans = getAttrib(VARCOVAR, im);
 	bool impute = FALSE;
 	double * imputationValues = 0;
-	if(!Rf_isNull(ans))
+	if(!isNull(ans))
 	{
 		impute = TRUE;
 		imputationValues = REAL(ans);
@@ -1090,10 +1091,10 @@ void setupChangingCovariateGroup(SEXP VARCOVARGROUP, Data *pData)
 {
 	if (Rf_length(VARCOVARGROUP) == 0)
 		return;
-	int observations = Rf_ncols(VECTOR_ELT(VARCOVARGROUP,0));
+	int observations = ncols(VECTOR_ELT(VARCOVARGROUP,0));
 	if (observations != pData->observationCount() - 1)
 	{
-		Rf_error ("wrong number of observations in Changing Covariate");
+		error ("wrong number of observations in Changing Covariate");
 	}
 	int nChangingCovariate = Rf_length(VARCOVARGROUP);
 	for (int changingCovariate = 0;
@@ -1101,20 +1102,20 @@ void setupChangingCovariateGroup(SEXP VARCOVARGROUP, Data *pData)
 			changingCovariate++)
 	{		
 		SEXP as;
-		PROTECT(as = Rf_install("nodeSet"));
-		SEXP actorSet = Rf_getAttrib(VECTOR_ELT(VARCOVARGROUP, changingCovariate),
+		PROTECT(as = install("nodeSet"));
+		SEXP actorSet = getAttrib(VECTOR_ELT(VARCOVARGROUP, changingCovariate),
 				as);
 		SEXP nm;
-		PROTECT(nm = Rf_install("name"));
-		SEXP name = Rf_getAttrib(VECTOR_ELT(VARCOVARGROUP, changingCovariate),
+		PROTECT(nm = install("name"));
+		SEXP name = getAttrib(VECTOR_ELT(VARCOVARGROUP, changingCovariate),
 				nm);
 		const ActorSet * pActorSet = pData->pActorSet(CHAR(STRING_ELT(
 						actorSet, 0)));
-		int nActors = Rf_nrows(VECTOR_ELT(VARCOVARGROUP,changingCovariate));
+		int nActors = nrows(VECTOR_ELT(VARCOVARGROUP,changingCovariate));
 
 		if (nActors != pActorSet->n())
 		{
-			Rf_error ("wrong number of actors");
+			error ("wrong number of actors");
 		}
 		ChangingCovariate * pChangingCovariate =
 			pData->createChangingCovariate(CHAR(STRING_ELT(name, 0)),
@@ -1122,11 +1123,11 @@ void setupChangingCovariateGroup(SEXP VARCOVARGROUP, Data *pData)
 		setupChangingCovariate(VECTOR_ELT(VARCOVARGROUP, changingCovariate),
 				pChangingCovariate);
 		SEXP mn;
-		PROTECT(mn = Rf_install("mean"));
-		SEXP obsmean = Rf_getAttrib(VECTOR_ELT(VARCOVARGROUP, changingCovariate), mn);
+		PROTECT(mn = install("mean"));
+		SEXP obsmean = getAttrib(VECTOR_ELT(VARCOVARGROUP, changingCovariate), mn);
 		SEXP cn;
-		PROTECT(cn = Rf_install("centered"));
-		SEXP ans = Rf_getAttrib(VECTOR_ELT(VARCOVARGROUP, changingCovariate), cn);
+		PROTECT(cn = install("centered"));
+		SEXP ans = getAttrib(VECTOR_ELT(VARCOVARGROUP, changingCovariate), cn);
 		bool centered = LOGICAL(ans)[0];
 		if (centered)
 		{
@@ -1137,16 +1138,16 @@ void setupChangingCovariateGroup(SEXP VARCOVARGROUP, Data *pData)
 			pChangingCovariate->mean(REAL(obsmean)[0]);
 		}
 		SEXP sim;
-		PROTECT(sim = Rf_install("simMean"));
-		SEXP simMean = Rf_getAttrib(VECTOR_ELT(VARCOVARGROUP, changingCovariate),
+		PROTECT(sim = install("simMean"));
+		SEXP simMean = getAttrib(VECTOR_ELT(VARCOVARGROUP, changingCovariate),
 				sim);
 		pChangingCovariate->similarityMean(REAL(simMean)[0]);
 		SEXP sims;
-		PROTECT(sims = Rf_install("simMeans"));
-		SEXP simMeans = Rf_getAttrib(VECTOR_ELT(VARCOVARGROUP, changingCovariate),
+		PROTECT(sims = install("simMeans"));
+		SEXP simMeans = getAttrib(VECTOR_ELT(VARCOVARGROUP, changingCovariate),
 				sims);
 		SEXP simNames;
-		PROTECT(simNames = Rf_getAttrib(simMeans, R_NamesSymbol));
+		PROTECT(simNames = getAttrib(simMeans, R_NamesSymbol));
 		int numberNetworks = Rf_length(simMeans);
 		for (int net = 0; net < numberNetworks; net++)
 		{
@@ -1154,8 +1155,8 @@ void setupChangingCovariateGroup(SEXP VARCOVARGROUP, Data *pData)
 					CHAR(STRING_ELT(simNames, net)));
 		}
 		SEXP range;
-		PROTECT(range = Rf_install("range"));
-		SEXP Range = Rf_getAttrib(VECTOR_ELT(VARCOVARGROUP, changingCovariate),
+		PROTECT(range = install("range"));
+		SEXP Range = getAttrib(VECTOR_ELT(VARCOVARGROUP, changingCovariate),
 				range);
 		pChangingCovariate->range(REAL(Range)[0]);
 		UNPROTECT(8);		
@@ -1171,7 +1172,7 @@ void setupDyadicCovariate(SEXP DYADVAR,
 {
 	double *start = REAL(VECTOR_ELT(DYADVAR, 0));
 	double *missingstart = REAL(VECTOR_ELT(DYADVAR, 1));
-	int listlen = Rf_ncols(VECTOR_ELT(DYADVAR, 0));
+	int listlen = ncols(VECTOR_ELT(DYADVAR, 0));
 	//	Rprintf("listlen =  %d\n", listlen);
 	int pos = 0;
 	for (int row = 0; row < listlen; row++)
@@ -1184,7 +1185,7 @@ void setupDyadicCovariate(SEXP DYADVAR,
 		val = start[pos++];
 		pConstantDyadicCovariate->value(i-1, j-1, val);
 	}
-	listlen = Rf_ncols(VECTOR_ELT(DYADVAR, 1));
+	listlen = ncols(VECTOR_ELT(DYADVAR, 1));
 	pos = 0;
 	for (int row = 0; row < listlen; row++)
 	{
@@ -1210,12 +1211,12 @@ void setupDyadicCovariateGroup(SEXP DYADVARGROUP, Data *pData)
 			dyadicCovariate++)
 	{
 		SEXP as;
-		PROTECT(as = Rf_install("nodeSet"));
-		SEXP actorSet = Rf_getAttrib(VECTOR_ELT(DYADVARGROUP, dyadicCovariate),
+		PROTECT(as = install("nodeSet"));
+		SEXP actorSet = getAttrib(VECTOR_ELT(DYADVARGROUP, dyadicCovariate),
 				as);
 		SEXP nm;
-		PROTECT(nm = Rf_install("name"));
-		SEXP name = Rf_getAttrib(VECTOR_ELT(DYADVARGROUP, dyadicCovariate),
+		PROTECT(nm = install("name"));
+		SEXP name = getAttrib(VECTOR_ELT(DYADVARGROUP, dyadicCovariate),
 				nm);
 		const ActorSet * myActorSet1 = pData->pActorSet(CHAR(STRING_ELT(
 						actorSet, 0)));
@@ -1227,8 +1228,8 @@ void setupDyadicCovariateGroup(SEXP DYADVARGROUP, Data *pData)
 		setupDyadicCovariate(VECTOR_ELT(DYADVARGROUP, dyadicCovariate),
 				pConstantDyadicCovariate);
 		SEXP mean;
-		PROTECT(mean = Rf_install("mean"));
-		SEXP Mean = Rf_getAttrib(VECTOR_ELT(DYADVARGROUP, dyadicCovariate),
+		PROTECT(mean = install("mean"));
+		SEXP Mean = getAttrib(VECTOR_ELT(DYADVARGROUP, dyadicCovariate),
 				mean);
 		pConstantDyadicCovariate->mean(REAL(Mean)[0]);
 		UNPROTECT(3);
@@ -1243,7 +1244,7 @@ void unpackChangingDyadicPeriod(SEXP VARDYADVALS, ChangingDyadicCovariate *
 		pChangingDyadicCovariate, int period)
 {
 	double *start = REAL(VECTOR_ELT(VARDYADVALS, 0));
-	int listlen = Rf_ncols(VECTOR_ELT(VARDYADVALS, 0));
+	int listlen = ncols(VECTOR_ELT(VARDYADVALS, 0));
 	//	Rprintf("listlen =  %d\n", listlen);
 	int pos = 0;
 	for (int row = 0; row < listlen; row++)
@@ -1257,7 +1258,7 @@ void unpackChangingDyadicPeriod(SEXP VARDYADVALS, ChangingDyadicCovariate *
 		pChangingDyadicCovariate->value(i - 1, j - 1, period, val);
 	}
 	double *missingstart = REAL(VECTOR_ELT(VARDYADVALS, 1));
-	listlen = Rf_ncols(VECTOR_ELT(VARDYADVALS, 1));
+	listlen = ncols(VECTOR_ELT(VARDYADVALS, 1));
 	//	Rprintf("listlen =  %d\n", listlen);
 	pos = 0;
 	for (int row = 0; row < listlen; row++)
@@ -1281,7 +1282,7 @@ void setupChangingDyadicObservations(SEXP VARDYAD,
 	int observations = Rf_length(VARDYAD);
 	//   if (observations != pworkLongitudinalData->observationCount())
 	// {
-	//	Rf_error ("wrong number of observations in OneMode");
+	//	error ("wrong number of observations in OneMode");
 	//  }
 	for (int period = 0; period < (observations - 1); period++)
 	{
@@ -1302,11 +1303,11 @@ void setupChangingDyadicCovariateGroup(SEXP VARDYADGROUP, Data * pData)
 			changingDyadic++)
 	{
 		SEXP as;
-		PROTECT(as = Rf_install("nodeSet"));
-		SEXP actorSet = Rf_getAttrib(VECTOR_ELT(VARDYADGROUP, changingDyadic), as);
+		PROTECT(as = install("nodeSet"));
+		SEXP actorSet = getAttrib(VECTOR_ELT(VARDYADGROUP, changingDyadic), as);
 		SEXP nm;
-		PROTECT(nm = Rf_install("name"));
-		SEXP name = Rf_getAttrib(VECTOR_ELT(VARDYADGROUP, changingDyadic), nm);
+		PROTECT(nm = install("name"));
+		SEXP name = getAttrib(VECTOR_ELT(VARDYADGROUP, changingDyadic), nm);
 		const ActorSet * myActorSet1 = pData->pActorSet(CHAR(STRING_ELT(
 						actorSet, 0)));
 		const ActorSet * myActorSet2 = pData->pActorSet(CHAR(STRING_ELT(
@@ -1318,8 +1319,8 @@ void setupChangingDyadicCovariateGroup(SEXP VARDYADGROUP, Data * pData)
 					changingDyadic),
 				pChangingDyadicCovariate);
 		SEXP mean;
-		PROTECT(mean = Rf_install("mean"));
-		SEXP Mean = Rf_getAttrib(VECTOR_ELT(VARDYADGROUP, changingDyadic),
+		PROTECT(mean = install("mean"));
+		SEXP Mean = getAttrib(VECTOR_ELT(VARDYADGROUP, changingDyadic),
 				mean);
 		pChangingDyadicCovariate->mean(REAL(Mean)[0]);
 		UNPROTECT(3);
@@ -1339,8 +1340,8 @@ void setupExogenousEventSet(SEXP EXOGEVENTSET, Data *pData)
 
 	/* first find the actor set */
 	SEXP as;
-	PROTECT(as = Rf_install("nodeSet"));
-	SEXP actorSet = Rf_getAttrib(EXOGEVENTSET, as);
+	PROTECT(as = install("nodeSet"));
+	SEXP actorSet = getAttrib(EXOGEVENTSET, as);
 
 	/* now process the events */
 	SEXP EVENTS = VECTOR_ELT(EXOGEVENTSET, 0);
@@ -1432,7 +1433,7 @@ SEXP createEffects(SEXP EFFECTS, Model *pModel, vector<Data *> * pGroupData,
 
 	/* set up a vector to return the pointers in */
 	SEXP effectPtrs;
-	PROTECT(effectPtrs = Rf_allocVector(VECSXP, nEffects));
+	PROTECT(effectPtrs = allocVector(VECSXP, nEffects));
 
 	for (int i = 0; i < nEffects; i++)
 	{
@@ -1493,7 +1494,7 @@ SEXP createEffects(SEXP EFFECTS, Model *pModel, vector<Data *> * pGroupData,
 				}
 				else
 				{
-					Rf_error("setting found for behavior variable %s",
+					error("setting found for behavior variable %s",
 							networkName);
 				}
 			}
@@ -1508,7 +1509,7 @@ SEXP createEffects(SEXP EFFECTS, Model *pModel, vector<Data *> * pGroupData,
 			}
 		else
 		{
-				Rf_error("setting found for variable %s", networkName);
+				error("setting found for variable %s", networkName);
 			}
 		}
 		else // no rate or scale effect
@@ -1546,7 +1547,7 @@ SEXP createInteractionEffects(SEXP EFFECTS, Model *pModel,
 
 	/* set up a vector to return the pointers in */
 	SEXP effectPtrs;
-	PROTECT(effectPtrs = Rf_allocVector(VECSXP, nEffects));
+	PROTECT(effectPtrs = allocVector(VECSXP, nEffects));
 
 	for (int i = 0; i < nEffects; i++)
 	{
@@ -1562,7 +1563,7 @@ SEXP createInteractionEffects(SEXP EFFECTS, Model *pModel,
 		EffectInfo * pEffect2 = (EffectInfo *) R_ExternalPtrAddr(
 				VECTOR_ELT(VECTOR_ELT(EFFECTS, intptr2Col), i));
 		EffectInfo * pEffect3 = 0;
-		if (!Rf_isNull(VECTOR_ELT(VECTOR_ELT(EFFECTS, intptr3Col), i)))
+		if (!isNull(VECTOR_ELT(VECTOR_ELT(EFFECTS, intptr3Col), i)))
 		{
 			pEffect3 = (EffectInfo *) R_ExternalPtrAddr(
 					VECTOR_ELT(VECTOR_ELT(EFFECTS, intptr3Col), i));
@@ -1595,8 +1596,8 @@ void getChangeContributionStatistics(SEXP EFFECTSLIST,
 {
 
 	// get the column names from the names attribute
-	SEXP cols = PROTECT(Rf_install("names"));
-	SEXP Names = Rf_getAttrib(VECTOR_ELT(EFFECTSLIST, 0), cols);
+	SEXP cols = PROTECT(install("names"));
+	SEXP Names = getAttrib(VECTOR_ELT(EFFECTSLIST, 0), cols);
 
 	int netTypeCol; /* net type */
 	int nameCol; /* network name */
@@ -1661,8 +1662,8 @@ void getActorStatistics(SEXP EFFECTSLIST,
 {
 
 	// get the column names from the names attribute
-	SEXP cols = PROTECT(Rf_install("names"));
-	SEXP Names = Rf_getAttrib(VECTOR_ELT(EFFECTSLIST, 0), cols);
+	SEXP cols = PROTECT(install("names"));
+	SEXP Names = getAttrib(VECTOR_ELT(EFFECTSLIST, 0), cols);
 
 	int netTypeCol; /* net type */
 	int nameCol; /* network name */
@@ -1726,8 +1727,8 @@ void getStatistics(SEXP EFFECTSLIST,
 
 	// get the column names from the names attribute
 	SEXP cols;
-	PROTECT(cols = Rf_install("names"));
-	SEXP Names = Rf_getAttrib(VECTOR_ELT(EFFECTSLIST, 0), cols);
+	PROTECT(cols = install("names"));
+	SEXP Names = getAttrib(VECTOR_ELT(EFFECTSLIST, 0), cols);
 
 	int netTypeCol; /* net type */
 	int nameCol; /* network name */
@@ -1957,7 +1958,7 @@ void getStatistics(SEXP EFFECTSLIST,
 						else
 						{
 
-							Rf_error("Unexpected rate effect %s\n",
+							error("Unexpected rate effect %s\n",
 									effectName);
 						}
 					}
@@ -1988,7 +1989,7 @@ void getStatistics(SEXP EFFECTSLIST,
 						}
 						else
 						{
-							Rf_error("Unexpected rate effect %s\n",
+							error("Unexpected rate effect %s\n",
 									effectName);
 						}
 					}
@@ -2036,7 +2037,7 @@ void getStatistics(SEXP EFFECTSLIST,
 						}
 						else
 						{
-							Rf_error("No individual covariate named %s.",
+							error("No individual covariate named %s.",
 									interaction1);
 						}
 					}
@@ -2119,7 +2120,7 @@ void getStatistics(SEXP EFFECTSLIST,
 				}
 				else
 				{
-					Rf_error("invalid effect type %s\n", effectType);
+					error("invalid effect type %s\n", effectType);
 				}
 			}
 			(*rfra)[istore] = statistic;
@@ -2145,8 +2146,8 @@ void getScores(SEXP EFFECTSLIST, int period, int group,
 {
 
 	// get the column names from the names attribute
-	SEXP cols = PROTECT(Rf_install("names"));
-	SEXP Names = Rf_getAttrib(VECTOR_ELT(EFFECTSLIST, 0), cols);
+	SEXP cols = PROTECT(install("names"));
+	SEXP Names = getAttrib(VECTOR_ELT(EFFECTSLIST, 0), cols);
 
 	int netTypeCol; /* net type */
 	int nameCol; /* network name */
@@ -2212,7 +2213,7 @@ void getScores(SEXP EFFECTSLIST, int period, int group,
 				}
 				else
 				{
-					Rf_error("Non constant rate effects are not yet %s",
+					error("Non constant rate effects are not yet %s",
 							"implemented for maximum likelihood.");
 				}
 			}
