@@ -13,8 +13,6 @@
 #define SIENA07UTILITIES_H_
 
 #include <Rinternals.h>
-#undef error
-#undef length
 
 #include "network/Network.h"
 #include "model/variables/DependentVariable.h"
@@ -22,6 +20,7 @@
 namespace siena
 {
 	class Data;
+    class ContinuousVariable;
 	class BehaviorVariable;
 	class Network;
 	class MiniStep;
@@ -58,6 +57,7 @@ void Rterminate();
 void printOutData(Data *pData);
 
 SEXP getBehaviorValues(const BehaviorVariable & behavior);
+SEXP getContinuousValues(const ContinuousVariable & behavior);
 SEXP getAdjacency(const Network& net);
 SEXP getEdgeList(const Network& net);
 
